# 环境要求

- [python3.6+](https://www.python.org/downloads/)
- [nodejs](https://nodejs.org/zh-cn/)
- [android-sdk](https://developer.android.com/studio#cmdline-tools)
- [jdk](https://www.oracle.com/java/technologies/javase-downloads.html)
- appium

# 安装方法

```python
pip install wasu-test==2.0
```